@@ -12,11 +12,14 @@ from enum import Enum
 from pathlib import Path
 from typing import List
 
-import structlog
 import xarray as xr
 from fastapi import HTTPException
+from loguru import logger
 
-from weather_provider_api.app_config import get_setting
+from weather_provider_api.config import APP_STORAGE_FOLDER
+from weather_provider_api.core.initializers.exception_handling import (
+    NOT_IMPLEMENTED_ERROR,
+)
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 
 
@@ -27,8 +30,7 @@ class RepositoryUpdateResult(Enum):
 
 
 class WeatherRepositoryBase(metaclass=ABCMeta):
-    """
-    This is the base class for all weather data storage repositories. Any new repositories should implement this
+    """This is the base class for all weather data storage repositories. Any new repositories should implement this
     as their base class.
     All valid stored repository files are named as follows:
     {file_prefix}_{file_identifier}.nc
@@ -38,29 +40,25 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
     """
 
     def __init__(self):
+        """Specification of required fields for a weather data storage repository:
+        - repository_folder:    Contains the folder where the repository will be saved. Is set inside a main
+                                repository folder, and based on a sub-folder passed by the repository itself
+                                through the _get_repo_subfolder() function.
+        - file_prefix:          Contains a string with the file_prefix to use for all files within the
+                                repository. Is set from the repository itself.
+        - runtime_limit:        Contains the maximum time the update function of the repository is allowed to be
+                                running, in seconds.
+        - first_day_of_repo:    Contains a datetime indicating the oldest moment allowed to be stored in the
+                                repository.
+        - last_day_of_repo:     Contains a datetime indicating the newest moment allowed to be stored in the
+                                repository.
+        - permanent_suffixes:   Contains a list of suffixes that can be added to the repository files to
+                                indicate that the file should not be deleted. Any file not matching the prefix
+                                or having a suffix not matching this list will be deleted upon cleanup.
+        - file_identifier_length:   This is the length in characters that the unique identifier part of the
+                                    filename takes up. Usually this is based on a datetime.
         """
-        Specification of required fields for a weather data storage repository:
-            - repository_folder:    Contains the folder where the repository will be saved. Is set inside a main
-                                    repository folder, and based on a sub-folder passed by the repository itself
-                                    through the _get_repo_subfolder() function.
-            - file_prefix:          Contains a string with the file_prefix to use for all files within the
-                                    repository. Is set from the repository itself.
-            - runtime_limit:        Contains the maximum time the update function of the repository is allowed to be
-                                    running, in seconds.
-            - first_day_of_repo:    Contains a datetime indicating the oldest moment allowed to be stored in the
-                                    repository.
-            - last_day_of_repo:     Contains a datetime indicating the newest moment allowed to be stored in the
-                                    repository.
-            - permanent_suffixes:   Contains a list of suffixes that can be added to the repository files to
-                                    indicate that the file should not be deleted. Any file not matching the prefix
-                                    or having a suffix not matching this list will be deleted upon cleanup.
-            - file_identifier_length:   This is the length in characters that the unique identifier part of the
-                                        filename takes up. Usually this is based on a datetime.
-        """
-        self.repository_folder = Path(get_setting("REPO_FOLDER")).joinpath(
-            self._get_repo_sub_folder()
-        )
-        self.logger = structlog.get_logger(__name__)
+        self.repository_folder = Path(APP_STORAGE_FOLDER).joinpath(self._get_repo_sub_folder())
         self.repository_name = None
         self.file_prefix = None
         self.runtime_limit = 60 * 60 * 2  # seconds * minutes * hours (2 hours default)
@@ -78,39 +76,29 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
     @staticmethod
     @abstractmethod
     def _get_repo_sub_folder():
-        print("This method is abstract and should be overridden.")
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
 
     def _validate_repo_folder(self):
-        """
-        This function checks whether the repository folder already exists (starting from its parent folder)
+        """This function checks whether the repository folder already exists (starting from its parent folder)
         and creates it, if it (or its parent folder) don't exist yet.
         """
-        if not Path(
-                self.repository_folder
-        ).exists():  # If the folder doesn't exist yet, create it
-            self.logger.debug(
-                f"Attempting to create folder[{self.repository_folder}]",
-                datetime=datetime.utcnow(),
-            )
+        if not Path(self.repository_folder).exists():  # If the folder doesn't exist yet, create it
+            logger.debug(f"Attempting to create folder[{self.repository_folder}]")
             try:
-                # If the main folder for all repositories doesn't exist yet, create it..
+                # If the main folder for all repositories doesn't exist yet, create it
                 if not Path(self.repository_folder).parent.exists():
                     Path(self.repository_folder).parent.mkdir()
                 Path(self.repository_folder).mkdir()
             except OSError as e:
-                self.logger.error(f"An error occurred creating the directory: {e}")
+                logger.error(f"An error occurred creating the directory: {e}")
                 raise e
 
     def cleanup(self):
-        """
-        This is the cleanup function for any Weather Repository.
+        """This is the cleanup function for any Weather Repository.
         Any files not matching the pattern required for the Repository shall be deleted.
         """
         self._validate_repo_folder()
-        self.logger.debug(
-            f"Verifying existing files for {self.repository_name} in [{self.repository_folder}]",
-            datetime=datetime.utcnow(),
-        )
+        logger.debug(f"Verifying existing files for {self.repository_name} in [{self.repository_folder}]")
 
         # Delete any files that aren't of a permanent type
         self._delete_non_permanent_files()
@@ -123,13 +111,10 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
 
     @abstractmethod
     def update(self):
-        print("This method is abstract and should be overridden.")
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
 
-    def gather_period(
-            self, begin: datetime, end: datetime, coordinates: List[GeoPosition]
-    ) -> xr.Dataset:
-        """
-            A function that gathers the repository files associated with a requested period, and then returns the full
+    def gather_period(self, begin: datetime, end: datetime, coordinates: List[GeoPosition]) -> xr.Dataset:
+        """A function that gathers the repository files associated with a requested period, and then returns the full
             weather data that matches both that period as the requested locations from those files, as a Xarray Dataset
         Args:
             begin:          A datetime holding the starting moment for the requested period to gather data for
@@ -140,29 +125,26 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
             the requested coordinates.
         """
         self.cleanup()
-        self.logger.debug(
-            f"Gathering repository data for the period of {begin} to {end}",
-            datetime=datetime.utcnow(),
-        )
+        logger.debug(f"Gathering repository data for the period of {begin} to {end}")
 
         # Get a list of files matching the requested period
         file_list = self._get_file_list_for_period(begin, end)
 
         if len(file_list) == 0:
-            self.logger.error(
-                f"No files were found for the period of {begin} to {end}",
-                datetime=datetime.utcnow(),
+            logger.error(f"No files were found for the period of {begin} to {end}")
+            raise HTTPException(
+                404,
+                f"No data was found for the period of [{begin.date()}] to [{end.date()}] in "
+                f"repository [{self.repository_name}]. As this range lies within the repository's "
+                f"storage timeframe of [{self.first_day_of_repo}] to [{self.last_day_of_repo}], "
+                f"we suggest retrying in a couple of days. If still no data is found at that time,"
+                f"please contact us at [weather.provider@alliander.com].",
             )
-            raise HTTPException(404, f"No data was found for the period of [{begin.date()}] to [{end.date()}] in "
-                                     f"repository [{self.repository_name}]. As this range lies within the repository's "
-                                     f"storage timeframe of [{self.first_day_of_repo}] to [{self.last_day_of_repo}], "
-                                     f"we suggest retrying in a couple of days. If still no data is found at that time,"
-                                     f"please contact us at [weather.provider@alliander.com].")
 
         # Load files into datasets, select the requested data and aggregate that into a single dataset
         ds = xr.Dataset()
         for file in file_list:
-            self.logger.debug(f'Processing file: {file}', datetime=datetime.utcnow())
+            logger.debug(f"Processing file: {file}")
             ds_temp = xr.open_dataset(file).load()
 
             ds_temp = self._filter_dataset_by_coordinates(coordinates, ds_temp)
@@ -172,9 +154,9 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
                 ds = ds.combine_first(ds_temp)
         return ds
 
-    def load_file(self, file: Path) -> xr.Dataset:
-        """
-            A function that loads and returns the full data for a specific repository file as a Xarray Dataset
+    @staticmethod
+    def load_file(file: Path) -> xr.Dataset:
+        """A function that loads and returns the full data for a specific repository file as a Xarray Dataset
         Args:
             file:   The filename (in the Path format by PathLib) specifying the file to load
         Returns:
@@ -186,25 +168,18 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
             return ds
 
         # Raise a FileNotFoundError if the file doesn't exist
-        self.logger.error(
-            f"File [{str(file)} does not exist]", datetime=datetime.utcnow()
-        )
+        logger.error(f"File [{file!s} does not exist]")
         raise FileNotFoundError
 
     def purge_repository(self):
+        """Function to fully delete the repository's folder and create a new clean one. Use with care!
         """
-        Function to fully delete the repository's folder and create a new clean one. Use with care!
-        """
-        self.logger.warning(
-            f"Purging the entire repository folder for {self.repository_name}!",
-            datetime=datetime.utcnow(),
-        )
+        logger.warning(f"Purging the entire repository folder for {self.repository_name}!")
         shutil.rmtree(self.repository_folder, ignore_errors=True)
         self._validate_repo_folder()  # Rebuild the folder after deletion
 
     def _delete_non_permanent_files(self):
-        """
-        A function that deletes any and all files in the repository's folder that are not considered permanent in
+        """A function that deletes any and all files in the repository's folder that are not considered permanent in
         nature. Only the files matching either repository files without a suffix or those with suffix listed in the
         permanent_suffixes field are allowed.
         Every other file should be deleted from the repository immediately.
@@ -212,18 +187,13 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
         # TODO: Enhance the detection of files that do not belong in the folder.
         #       A repository folder should only have repository files..
         len_filename_until_after_date = (
-                len(str(self.repository_folder.joinpath(self.file_prefix)))
-                + self.file_identifier_length
-                + 2
+            len(str(self.repository_folder.joinpath(self.file_prefix))) + self.file_identifier_length + 2
         )
-        for file_name in glob.glob(
-                str(self.repository_folder.joinpath(self.file_prefix)) + "*.nc"
-        ):
+        for file_name in glob.glob(str(self.repository_folder.joinpath(self.file_prefix)) + "*.nc"):
             file_suffix = file_name[len_filename_until_after_date:-3]
             if len(file_suffix) != 0 and file_suffix not in self.permanent_suffixes:
-                self.logger.debug(
-                    f"File [{file_name}] is not a permanent file for {self.repository_name} "
-                    f"and needs to be deleted"
+                logger.debug(
+                    f"File [{file_name}] is not a permanent file for {self.repository_name} and needs to be deleted"
                 )
                 self._safely_delete_file(file_name)
 
@@ -232,22 +202,15 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
         pass
 
     def _delete_excess_files(self):
-        """
-        A function that selects the proper file to keep when more than one permanent file exists for a given
+        """A function that selects the proper file to keep when more than one permanent file exists for a given
         identifier. The other files are deleted.
         """
-        len_filename_until_date = (
-                len(str(self.repository_folder.joinpath(self.file_prefix))) + 1
-        )
-        file_list = glob.glob(
-            str(self.repository_folder.joinpath(self.file_prefix)) + "*.*"
-        )
+        len_filename_until_date = len(str(self.repository_folder.joinpath(self.file_prefix))) + 1
+        file_list = glob.glob(str(self.repository_folder.joinpath(self.file_prefix)) + "*.*")
         identifier_list = list(
             set(
                 [
-                    file[
-                        len_filename_until_date: len_filename_until_date + self.file_identifier_length
-                    ]
+                    file[len_filename_until_date : len_filename_until_date + self.file_identifier_length]
                     for file in file_list
                 ]
             )
@@ -255,23 +218,16 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
 
         for identifier in identifier_list:
             files_with_specific_identifier = glob.glob(
-                str(self.repository_folder.joinpath(self.file_prefix))
-                + "_"
-                + identifier
-                + "*.nc"
+                str(self.repository_folder.joinpath(self.file_prefix)) + "_" + identifier + "*.nc"
             )
 
             if len(files_with_specific_identifier) > 1:
-                self.logger.debug(
-                    f"More than one file was found for identifier [{identifier}]"
-                )
+                logger.debug(f"More than one file was found for identifier [{identifier}]")
                 file_to_retain = None
                 highest_ranking_suffix = None
 
                 for file in files_with_specific_identifier:
-                    suffix = file[
-                             len_filename_until_date + self.file_identifier_length + 1: -3
-                             ]
+                    suffix = file[len_filename_until_date + self.file_identifier_length + 1 : -3]
 
                     if highest_ranking_suffix is None or suffix == "":
                         highest_ranking_suffix = suffix
@@ -287,30 +243,28 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
                     if file != file_to_retain:
                         self._safely_delete_file(str(Path(file)))
 
-    def _safely_delete_file(self, file: str):
-        """ Basic function to safely remove files from the repository if possible, and supply errors if not """
+    @staticmethod
+    def _safely_delete_file(file: str):
+        """Basic function to safely remove files from the repository if possible, and supply errors if not"""
         try:
-            self.logger.debug(
-                f"Safely deleting file [{file}]", datetime=datetime.utcnow()
-            )
+            logger.debug(f"Safely deleting file [{file}]")
             Path(file).unlink()
         except OSError as e:
-            self.logger.error(f"Could not safely delete file: {e}")
+            logger.error(f"Could not safely delete file: {e}")
             raise OSError(f"Could not safely delete file: {file}")
         return True
 
     @abstractmethod
     def _get_file_list_for_period(self, start: datetime, end: datetime):
-        print("This method is abstract and should be overridden.")
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
+
+    def _filter_dataset_by_coordinates(self, coordinates: List[GeoPosition], ds: xr.Dataset) -> xr.Dataset:
+        """A function that filters a given Xarray Dataset down to the values matching a given list of locations.
 
-    def _filter_dataset_by_coordinates(
-            self, coordinates: List[GeoPosition], ds: xr.Dataset
-    ) -> xr.Dataset:
-        """
-            A function that filters a given Xarray Dataset down to the values matching a given list of locations.
         Args:
             coordinates:    A list of GeoPositions that the data is requested for.
             ds:             An Xarray Dataset containing the data to be filtered.
+
         Returns:
             An Xarray Dataset containing only the weather data that matched the given list of coordinates.
         """
@@ -320,11 +274,9 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
         for coordinate in coordinate_list:
             # First filter a single coordinate in the list
             ds_single_coord = ds.stack(dimensions={"coord": ["lat", "lon"]})
+            ds_single_coord = ds_single_coord.where(ds_single_coord.lat == coordinate.get_WGS84()[0], drop=True)
             ds_single_coord = ds_single_coord.where(
-                ds_single_coord.lat == coordinate.get_WGS84()[0], drop=True
-            )
-            ds_single_coord = ds_single_coord.where(
-                ds_single_coord.lon.round(3) == coordinate.get_WGS84()[1], drop=True
+                ds_single_coord.lon.round(3) == coordinate.get_WGS84()[1].round(3), drop=True
             )
             ds_single_coord = ds_single_coord.unstack("coord")
             # Then append this to a clean list
@@ -337,5 +289,4 @@ class WeatherRepositoryBase(metaclass=ABCMeta):
 
     @abstractmethod
     def get_grid_coordinates(self, coordinates: List[GeoPosition]) -> List[GeoPosition]:
-        self.logger.error("This method is abstract and should be overridden.")
-        raise NotImplementedError()
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
